@@ -14,5 +14,5 @@ pub fn sql(sql_raw: &str) -> SqlLiteral {
 pub use traits::ArelAble;
 
 pub use arel_macro::arel;
-// derive 废弃
-// pub use arel_macro::Arel;
\ No newline at end of file
+
+pub mod prelude;
\ No newline at end of file
