@@ -1,7 +1,7 @@
 use std::any::type_name;
 use inflector::{string::{demodulize, pluralize}, cases::snakecase};
 use regex::Regex;
-use crate::traits::ModelAble;
+use crate::traits::ArelAble;
 
 pub fn type_to_pluralize_string<M>() -> String where M: ?Sized {
     // eg: arel::UserTable
@@ -11,7 +11,7 @@ pub fn type_to_pluralize_string<M>() -> String where M: ?Sized {
     // eg: user_table
     let snake_struct_name = snakecase::to_snake_case(&struct_name);
     // eg: user_tables
-    pluralize::to_plural(&snake_struct_name)
+    pluralize::to_plural(Regex::new(r"_arel$").unwrap().replace(&snake_struct_name, "").as_ref())
 }
 
 /// Get Model's table field name.
@@ -19,17 +19,16 @@ pub fn type_to_pluralize_string<M>() -> String where M: ?Sized {
 /// # Examples
 ///
 /// ```
-/// use arel::traits::ModelAble;
+/// use arel::traits::ArelAble;
 /// use arel::methods::table_column_name;
 ///
-/// #[derive(Clone, Debug)]
+/// #[arel::arel]
 /// struct User {}
-/// impl ModelAble for User {}
 /// assert_eq!(table_column_name::<User>("*"), "`users`.*");
 /// assert_eq!(table_column_name::<User>("age"), "`users`.`age`");
 /// assert_eq!(table_column_name::<User>("users.name"), "users.name");
 /// ```
-pub fn table_column_name<M: ModelAble>(column_name: &str) -> String {
+pub fn table_column_name<M: ArelAble>(column_name: &str) -> String {
     if column_name == "*" {
         format!("`{}`.{}", M::table_name(), column_name)
     } else if Regex::new(r"\.").unwrap().is_match(column_name) {
