@@ -1,6 +1,7 @@
+#[allow(dead_code)]
 pub use crate::{arel, ArelAble};
 pub use sqlx::{self, Row};
 
 #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
-pub use sqlx::{any};
+pub use sqlx::any;
 pub use serde_json::{Value as Json, json};
\ No newline at end of file
