@@ -351,4 +351,10 @@ impl<M> Table<M> where M: ArelAble {
         let rows = sqlx::query(&sql).fetch_all(db_state.pool()).await?;
         rows.into_iter().map(|row| M::new_from_db_row(row)).collect()
     }
+    pub async fn execute(&mut self) -> anyhow::Result<sqlx::any::AnyQueryResult> {
+        let sql = self.to_sql()?;
+        let db_state = crate::visitors::get_db_state()?;
+        let query_result = sqlx::query(&sql).execute(db_state.pool()).await?;
+        Ok(query_result)
+    }
 }
\ No newline at end of file
