@@ -1,17 +1,17 @@
 use serde_json::{Value as Json};
 use std::marker::PhantomData;
-use crate::traits::ModelAble;
+use crate::traits::ArelAble;
 use crate::statements::{Join, StatementAble};
 
 #[derive(Clone, Debug)]
-pub struct JoinSource<M: ModelAble> {
+pub struct JoinSource<M: ArelAble> {
     join: Join<M>,
     // left: Option<StatementsType<M>>,
     // right: Option<StatementsType<M>>,
     _marker: PhantomData<M>,
 }
 
-impl<M> JoinSource<M> where M: ModelAble {
+impl<M> JoinSource<M> where M: ArelAble {
     pub fn new(condition: Json) -> Self {
         Self {
             join: Join::<M>::new(condition),
