@@ -3,6 +3,7 @@ use once_cell::sync::OnceCell;
 
 // use sqlx::sqlite::{SqlitePool};
 use sqlx::any::{AnyPool};
+use crate::visitors::db_transaction::{DbTransaction};
 
 #[derive(Debug)]
 pub struct DbState {
@@ -19,11 +20,35 @@ impl DbState {
     // db_state.exec(async move |db_state: &DbState| {
     //     Ok(())
     // }).await?;
-    // pub async fn exec<'a: 'b, 'b, Fut>(&'a self, f: impl FnOnce(&'b DbState) -> Fut) -> anyhow::Result<()>
-    //     where Fut: Future<Output = anyhow::Result<()>> {
-    //     f(&self).await?;
-    //     Ok(())
-    // }
+    pub async fn transaction(&self) -> anyhow::Result<()> {
+
+        let mut transaction = DbTransaction::new(self.pool().begin().await?);
+        transaction.execute().await
+
+
+
+        // f(tx).await
+        // match {
+        //     f(tx).await
+        // } {
+        //     Ok(()) => {
+        //         match tx.commit().await {
+        //             Ok(()) => Ok(()),
+        //             Err(err) => Err(err.into())
+        //         }
+        //     },
+        //     Err(err) => Err(err),
+        // }
+        // match f(&mut tx).await {
+        //     Ok(()) => {
+        //         match tx.commit().await {
+        //             Ok(()) => Ok(()),
+        //             Err(err) => Err(err.into())
+        //         }
+        //     },
+        //     Err(err) => Err(err),
+        // }
+    }
 }
 
 pub static DB_STATE_CELL: OnceCell<DbState>  = OnceCell::new();
