@@ -1,11 +1,9 @@
-use arel::traits::ModelAble;
+use arel::{ArelAble};
 use serde_json::json;
 
-#[derive(Clone, Debug)]
+#[arel::arel]
 struct User {}
 
-impl ModelAble for User {}
-
 #[cfg(test)]
 mod insert {
     use super::*;
