@@ -1,9 +1,9 @@
-use arel::{ArelAble};
-use serde_json::json;
+use arel::prelude::*;
 
-#[arel::arel]
+#[arel]
 struct User {}
 
+#[allow(dead_code)]
 #[cfg(test)]
 mod query {
     use super::*;
