@@ -45,6 +45,10 @@ mod sqlite_sqlx {
         let users = User::query().fetch_all().await?;
         assert_eq!(users.len(), 10);
 
+        User::update_all(json!({"desc": "update_1"})).execute().await?;
+        let user = User::query().fetch_one().await?;
+        assert_eq!(user.desc(), Some(&"update_1".to_string()));
+
         Ok(())
     }
 
